@@ -106,7 +106,7 @@ class Interface(Blocks):
 
     def __init__(
         self,
-        fn: Callable | List[Callable],
+        fn: Callable,
         inputs: Optional[str | Component | List[str | Component]],
         outputs: Optional[str | Component | List[str | Component]],
         examples: Optional[List[Any] | List[List[Any]] | str] = None,
@@ -172,6 +172,12 @@ class Interface(Blocks):
 
         if not isinstance(fn, list):
             fn = [fn]
+        else:
+            raise DeprecationWarning(
+                "The `fn` parameter only accepts a single function, support for a list "
+                "of functions has been deprecated. Please use gradio.mix.Parallel "
+                "instead."
+            )
         if not isinstance(inputs, list):
             inputs = [inputs]
         if not isinstance(outputs, list):
@@ -545,6 +551,7 @@ class Interface(Blocks):
                     self.input_components,
                     self.output_components,
                     api_name="predict",
+                    scroll_to_output=True,
                     status_tracker=status_tracker,
                 )
             clear_btn.click(
