@@ -1,32 +1,51 @@
 """
 Ways to transform interfaces to produce new interfaces
 """
+import warnings
+
 import gradio
 
 
 class Parallel(gradio.Interface):
     """
-    Creates a new Interface consisting of multiple models in parallel
-    Parameters:
-    interfaces: any number of Interface objects that are to be compared in parallel
-    options: additional kwargs that are passed into the new Interface object to customize it
-    Returns:
-    (Interface): an Interface object comparing the given models
+    Creates a new Interface consisting of multiple models in parallel (comparing their outputs).
+    The Interfaces to put in Parallel must share the same input components (but can have different output components).
     """
 
     def __init__(self, *interfaces, **options):
+        """
+        Parameters:
+        *interfaces (Interface): any number of Interface objects that are to be compared in parallel
+        **options (optional): additional kwargs that are passed into the new Interface object to customize it
+        Returns:
+        (Interface): an Interface object comparing the given models
+        """
         fns = []
         outputs = []
 
         for io in interfaces:
+            if not (isinstance(io, gradio.Interface)):
+                warnings.warn(
+                    "Parallel may not work properly with non-Interface objects."
+                )
             fns.extend(io.predict)
             outputs.extend(io.output_components)
 
+        def parallel_fn(*args):
+            return_values = []
+            for fn in fns:
+                value = fn(*args)
+                if isinstance(value, tuple):
+                    return_values.extend(value)
+                else:
+                    return_values.append(value)
+            return return_values
+
         kwargs = {
-            "fn": fns,
+            "fn": parallel_fn,
             "inputs": interfaces[0].input_components,
             "outputs": outputs,
-            "repeat_outputs_per_model": False,
+            "_repeat_outputs_per_model": False,
         }
         kwargs.update(options)
         super().__init__(**kwargs)
@@ -37,16 +56,25 @@ class Parallel(gradio.Interface):
 
 class Series(gradio.Interface):
     """
-    Creates a new Interface from multiple models in series (the output of one is fed as the input to the next)
-    Parameters:
-    interfaces: any number of Interface objects that are to be connected in series
-    options: additional kwargs that are passed into the new Interface object to customize it
-    Returns:
-    (Interface): an Interface object connecting the given models
+    Creates a new Interface from multiple models in series (the output of one is fed as the input to the next,
+    and so the input and output components must agree between the interfaces).
     """
 
     def __init__(self, *interfaces, **options):
-        fns = [io.predict for io in interfaces]
+        """
+        Parameters:
+        *interfaces (Interface): any number of Interface objects that are to be connected in series
+        **options (optional): additional kwargs that are passed into the new Interface object to customize it
+        Returns:
+        (Interface): an Interface object connecting the given models
+        """
+        fns = []
+        for io in interfaces:
+            if not (isinstance(io, gradio.Interface)):
+                warnings.warn(
+                    "Series may not work properly with non-Interface objects."
+                )
+            fns.append(io.predict)
 
         def connected_fn(
             *data,
